@@ -13,8 +13,8 @@ from torch.utils.data import Dataset, IterableDataset, DataLoader
 import mlflow
 import pytorch_lightning as pl
 from pytorch_lightning.loggers import WandbLogger
-from src.lighting.callbacks_base import AttnVisCallbackBase, MLflowCallbackBase, TensorboardCallbackBase
-from src.models.multitask import MultiTaskTxT, MultiTaskTxE
+from .callbacks_base import AttnVisCallbackBase, MLflowCallbackBase, TensorboardCallbackBase
+from ..models.multitask import MultiTaskTxT, MultiTaskTxE
 from pytorch_lightning import LightningModule
 
 
